==> skrooge_0.2.5.orig.tar.gz: skrooge-0.2.5/skgbasegui/skgcalculatoreditdesignerplugin.cpp <==
/***************************************************************************
 *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@miraks.com    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>  *
 ***************************************************************************/
/** @file
 * A KLineEdit with calculator included for skrooge (qt designer plugin).
 *
 * @author Stephane MANKOWSKI / Guillaume DE BURE
 */
#include "skgcalculatoreditdesignerplugin.h"
#include "skgcalculatoredit.h"

#include "kicon.h"

#include <QtPlugin>

SKGCalculatorEditDesignerPlugin::SKGCalculatorEditDesignerPlugin(QObject *parent)
                : QObject(parent)
{
        initialized = false;
}

void SKGCalculatorEditDesignerPlugin::initialize(QDesignerFormEditorInterface * /* core */)
{
        if (initialized) return;

        initialized = true;
}

bool SKGCalculatorEditDesignerPlugin::isInitialized() const
{
        return initialized;
}

QWidget *SKGCalculatorEditDesignerPlugin::createWidget(QWidget *parent)
{
        return new SKGCalculatorEdit(parent);
}

QString SKGCalculatorEditDesignerPlugin::name() const
{
        return "SKGCalculatorEdit";
}

QString SKGCalculatorEditDesignerPlugin::group() const
{
        return "SKG Widgets";
}

QIcon SKGCalculatorEditDesignerPlugin::icon() const
{
        return KIcon("skrooge.png");
}

QString SKGCalculatorEditDesignerPlugin::toolTip() const
{
        return "A KLineEdit with calculator included used by skrooge";
}

QString SKGCalculatorEditDesignerPlugin::whatsThis() const
{
        return "A KLineEdit with calculator included used by skrooge";
}

bool SKGCalculatorEditDesignerPlugin::isContainer() const
{
        return false;
}

QString SKGCalculatorEditDesignerPlugin::domXml() const
{
        return "<widget class=\"SKGCalculatorEdit\" name=\"SKGCalculatorEdit\">\n"
               " <property name=\"geometry\">\n"
               "  <rect>\n"
               "   <x>0</x>\n"
               "   <y>0</y>\n"
               "   <width>100</width>\n"
               "   <height>10</height>\n"
               "  </rect>\n"
               " </property>\n"
               "</widget>\n";
}

QString SKGCalculatorEditDesignerPlugin::includeFile() const
{
        return "skgcalculatoredit.h";
}

==> skrooge_0.6.0.orig.tar.gz: skrooge-0.6.0/skgbasegui/skgcalculatoreditdesignerplugin.cpp <==
/***************************************************************************
 *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>  *
 ***************************************************************************/
/** @file
 * A KLineEdit with calculator (qt designer plugin).
 *
 * @author Stephane MANKOWSKI / Guillaume DE BURE
 */
#include "skgcalculatoreditdesignerplugin.h"
#include "skgcalculatoredit.h"

#include "kicon.h"

#include <QtPlugin>

SKGCalculatorEditDesignerPlugin::SKGCalculatorEditDesignerPlugin(QObject *parent)
                : QObject(parent)
{
        initialized = false;
}

void SKGCalculatorEditDesignerPlugin::initialize(QDesignerFormEditorInterface * /* core */)
{
        if (initialized) return;

        initialized = true;
}

bool SKGCalculatorEditDesignerPlugin::isInitialized() const
{
        return initialized;
}

QWidget *SKGCalculatorEditDesignerPlugin::createWidget(QWidget *parent)
{
        return new SKGCalculatorEdit(parent);
}

QString SKGCalculatorEditDesignerPlugin::name() const
{
        return "SKGCalculatorEdit";
}

QString SKGCalculatorEditDesignerPlugin::group() const
{
        return "SKG Widgets";
}

QIcon SKGCalculatorEditDesignerPlugin::icon() const
{
        return KIcon("skg_open");
}

QString SKGCalculatorEditDesignerPlugin::toolTip() const
{
        return "A KLineEdit with calculator included";
}

QString SKGCalculatorEditDesignerPlugin::whatsThis() const
{
        return "A KLineEdit with calculator included";
}

bool SKGCalculatorEditDesignerPlugin::isContainer() const
{
        return false;
}

QString SKGCalculatorEditDesignerPlugin::domXml() const
{
        return "<widget class=\"SKGCalculatorEdit\" name=\"SKGCalculatorEdit\">\n"
               " <property name=\"geometry\">\n"
               "  <rect>\n"
               "   <x>0</x>\n"
               "   <y>0</y>\n"
               "   <width>100</width>\n"
               "   <height>10</height>\n"
               "  </rect>\n"
               " </property>\n"
               "</widget>\n";
}

QString SKGCalculatorEditDesignerPlugin::includeFile() const
{
        return "skgcalculatoredit.h";
}
